/**
 * The default UI Config
 */
export const defaultConfig = {
  designTokens: {
    spacingBase: 4,
    googleFont: 'Inter',
  },
  styles: {
    // 'dyte-meeting': {
    // NOTE(vaibhavshn): required for mobile devices with static positioning
    // not required for fixed position
    // height: '-webkit-fill-available',
    // },
    'dyte-header': {
      display: 'grid',
      height: '48px',
      gridTemplateColumns: 'repeat(3, 1fr)',
      gridTemplateRows: '1fr',
      alignItems: 'center',
    },
    'dyte-header.sm': {
      display: 'grid',
      gridArea: 'header',
      gridTemplateColumns: 'repeat(2, 1fr)',
      gridTemplateRows: '1fr',
      alignItems: 'center',
    },
    'div#header-left': {
      display: 'flex',
      alignItems: 'center',
      height: '48px',
    },
    'dyte-logo': {
      height: '26px',
    },
    'div#header-center': {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
    },
    'div#header-right': {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
    },
    'dyte-stage': {
      display: 'flex',
      flex: '1',
    },
    'dyte-grid': {
      flex: '1',
      height: 'auto',
    },
    'dyte-controlbar': {
      display: 'grid',
      height: '76px',
      gridTemplateColumns: 'repeat(3,1fr)',
      gridTemplateRows: '1fr',
      alignItems: 'center',
      padding: '8px',
    },
    'dyte-controlbar.sm': {
      display: 'flex',
      position: 'relative',
      backgroundColor: 'rgb(var(--dyte-colors-background-1000, 0 0 0))',
    },
    'div#controlbar-left': {
      display: 'flex',
      alignItems: 'center',
    },
    'div#controlbar-center': {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
    },
    'div#controlbar-mobile': {
      display: 'flex',
      flex: '1',
      alignItems: 'center',
      justifyContent: 'center',
    },
    'div#controlbar-right': {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
    },
    'dyte-settings': {
      width: '720px',
      height: '480px',
    },
    'div#more-menu': {
      position: 'absolute',
      boxSizing: 'border-box',
      top: '0',
      left: '0',
      width: '100%',
      transform: 'translateY(-100%)',
      backgroundColor: 'var(--dyte-colors-background-1000, #000)',
      padding: '16px 12px',
      borderRadius: '18px 18px 0 0',
    },
    'div#setupcontrols-media': {
      position: 'absolute',
      bottom: '8px',
      right: '8px',
      display: 'flex',
    },
    'div#setupcontrols-settings': {
      position: 'absolute',
      top: '8px',
      right: '8px',
    },
  },
  root: {
    'dyte-meeting': {
      // if using key value pair, provide the key in `state`
      // else provide array of states in `states`
      state: 'meeting',
      states: ['activeSidebar'],
    },
    'dyte-meeting[meeting=idle]': ['dyte-idle-screen'],
    'dyte-meeting[meeting=setup]': ['dyte-setup-screen', 'dyte-dialog-manager'],
    'dyte-meeting[meeting=joined]': [
      'dyte-header',
      'dyte-stage',
      'dyte-controlbar',
      'dyte-participants-audio',
      'dyte-dialog-manager',
    ],
    'dyte-meeting[meeting=joined].activeSidebar.sm': [
      'dyte-header',
      'dyte-stage',
      'dyte-controlbar',
      'dyte-participants-audio',
      'dyte-dialog-manager',
      ['dyte-sidebar', { view: 'full-screen' }],
    ],
    'dyte-meeting[meeting=joined].activeSidebar.md': [
      'dyte-header',
      'dyte-stage',
      'dyte-controlbar',
      'dyte-participants-audio',
      'dyte-dialog-manager',
      ['dyte-sidebar', { view: 'full-screen' }],
    ],
    'dyte-meeting[meeting=ended]': ['dyte-ended-screen'],
    'dyte-header': {
      children: ['div#header-left', 'div#header-center', 'div#header-right'],
    },
    'dyte-header.sm': ['div#header-left', 'div#header-right'],
    'div#header-left': ['dyte-logo', 'dyte-recording-indicator'],
    'div#header-center': ['dyte-meeting-title'],
    'div#header-right': ['dyte-grid-pagination', 'dyte-clock', 'dyte-participant-count'],
    'dyte-logo': {
      props: {
        logo: '',
        config: {
          designTokens: {
            logo: 'https://app.dyte.io/dyte-logo/dyte.svg',
          },
        },
      },
    },
    'dyte-stage': {
      states: ['activeSidebar'],
      children: ['dyte-grid', 'dyte-notifications'],
    },
    'dyte-stage.activeSidebar': [
      'dyte-grid',
      'dyte-notifications',
      ['dyte-sidebar', { view: 'sidebar' }],
    ],
    // hide sidebar for smaller screens
    'dyte-stage.activeSidebar.sm': ['dyte-grid', 'dyte-notifications'],
    'dyte-grid': {
      states: ['activeScreenShare', 'activePlugin', 'activeSpotlight'],
      children: ['dyte-simple-grid'],
    },
    'dyte-grid.activeSpotlight': ['dyte-spotlight-grid'],
    'dyte-grid.activeScreenShare': ['dyte-mixed-grid'],
    'dyte-grid.activePlugin': ['dyte-mixed-grid'],
    'dyte-grid.activeScreenShare.activeSpotlight': ['dyte-mixed-grid'],
    'dyte-grid.activePlugin.activeSpotlight': ['dyte-mixed-grid'],
    'dyte-mixed-grid': {
      states: ['activeSpotlight'],
      children: ['dyte-simple-grid'],
    },
    'dyte-mixed-grid.activeSpotlight': ['dyte-spotlight-grid'],
    'dyte-participant-tile': {
      state: 'meeting',
      children: ['dyte-name-tag', 'dyte-avatar'],
    },
    'dyte-participant-tile[meeting=setup]': {
      children: ['dyte-avatar', 'div#setupcontrols-settings', 'div#setupcontrols-media'],
    },
    'div#setupcontrols-media': [
      ['dyte-mic-toggle', { size: 'sm' }],
      ['dyte-camera-toggle', { size: 'sm' }],
    ],
    'div#setupcontrols-settings': [['dyte-settings-toggle', { size: 'sm' }]],
    'dyte-screenshare-view': {
      children: ['dyte-name-tag'],
    },
    'dyte-name-tag': [['dyte-audio-visualizer', { slot: 'start' }]],
    'dyte-controlbar': {
      states: ['activeMoreMenu'],
      props: {
        variant: 'solid',
      },
      children: ['div#controlbar-left', 'div#controlbar-center', 'div#controlbar-right'],
    },
    'dyte-controlbar.sm': ['div#controlbar-mobile'],
    'dyte-controlbar.md': ['div#controlbar-mobile'],
    'dyte-controlbar.activeMoreMenu.sm': ['div#controlbar-mobile', 'div#more-menu'],
    'dyte-controlbar.activeMoreMenu.md': ['div#controlbar-mobile', 'div#more-menu'],
    'div#controlbar-mobile': [
      'dyte-mic-toggle',
      'dyte-camera-toggle',
      'dyte-leave-button',
      'dyte-more-toggle',
    ],
    'div#more-menu': [
      ['dyte-chat-toggle', { variant: 'horizontal' }],
      ['dyte-participants-toggle', { variant: 'horizontal' }],
      ['dyte-polls-toggle', { variant: 'horizontal' }],
      ['dyte-plugins-toggle', { variant: 'horizontal' }],
      ['dyte-fullscreen-toggle', { variant: 'horizontal' }],
      ['dyte-screenshare-toggle', { variant: 'horizontal' }],
      ['dyte-settings-toggle', { variant: 'horizontal' }],
    ],
    'div#controlbar-left': [
      'dyte-leave-button',
      'dyte-screen-share-toggle',
      'dyte-fullscreen-toggle',
      'dyte-recording-toggle',
    ],
    'div#controlbar-center': ['dyte-mic-toggle', 'dyte-camera-toggle', 'dyte-settings-toggle'],
    'div#controlbar-right': [
      'dyte-chat-toggle',
      'dyte-polls-toggle',
      'dyte-participants-toggle',
      'dyte-plugins-toggle',
    ],
  },
  config: {
    notifications: ['chat', 'participant_joined', 'participant_left'],
    notification_sounds: ['chat', 'participant_joined'],
    participant_joined_sound_notification_limit: 10,
    participant_chat_message_sound_notification_limit: 10,
    videoFit: 'cover',
  },
};
